@@ -1,7 +1,7 @@
 import os
 import secrets
 import threading
-from typing import Dict, Optional, Type, Union, cast
+from typing import Any, Dict, Optional, Type, Union, cast
 
 from chaosaddons.controls import safeguards
 from chaoslib.run import EventHandlerRegistry, RunEventHandler
@@ -14,6 +14,8 @@ from chaoslib.types import (
 )
 from logzero import logger
 
+global_lock = threading.Lock()
+
 
 class ReliablyGuardian(safeguards.Guardian):  # type: ignore
     def _exit(self) -> None:
@@ -29,6 +31,7 @@ class ReliablySafeguardGuardian:
         guardian_class: Type[safeguards.Guardian] = ReliablyGuardian,
     ) -> None:
         self.guardian = guardian_class()
+        self.frequency = frequency
 
         url = get_value(url)  # type: ignore
         auth = get_value(auth)  # type: ignore
@@ -77,9 +80,16 @@ class ReliablySafeguardGuardian:
             None,
         )
 
-    def finish(self) -> None:
+    def finish(self, journal: Journal) -> None:
         self.guardian.terminate()
-        self.probes = []
+
+        with global_lock:
+            if self.guardian.was_triggered:
+                x = journal["experiment"]
+                name = "safeguards" if self.frequency else "prechecks"
+                integration = get_integration_from_extension(x, name)
+                trig_probes = integration.setdefault("triggered_probes", [])
+                trig_probes.append(self.guardian.triggered_by_run)
 
 
 class ReliablySafeguardHandler(RunEventHandler):  # type: ignore
@@ -88,6 +98,7 @@ class ReliablySafeguardHandler(RunEventHandler):  # type: ignore
         self._lock = threading.Lock()
         self._initialized = False
         self._started = False
+
         self.guardians = []  # type: ignore
 
     @property
@@ -115,6 +126,12 @@ class ReliablySafeguardHandler(RunEventHandler):  # type: ignore
         if not self.initialized:
             return None
 
+        extension = find_extension_by_name(experiment, "reliably")
+        if extension:
+            intg = extension.setdefault("integrations", {})
+            intg.setdefault("prechecks", [])
+            intg.setdefault("safeguards", [])
+
         with self._lock:
             if self._started:
                 return None
@@ -130,7 +147,10 @@ class ReliablySafeguardHandler(RunEventHandler):  # type: ignore
 
         with self._lock:
             for g in self.guardians:
-                g.finish()
+                try:
+                    g.finish(journal)
+                except Exception:
+                    logger.debug("Guardian somehow failed", exc_info=True)
 
     def add(self, guardian: ReliablySafeguardGuardian) -> None:
         if not self.initialized:
@@ -174,7 +194,8 @@ def run_all(
 
 
 def find_extension_by_name(
-    experiment: Experiment, name: str
+    experiment: Experiment,
+    name: str,
 ) -> Optional[Extension]:
     extensions = experiment.get("extensions")
     if not extensions:
@@ -201,3 +222,20 @@ def get_value(value: Union[str, Dict[str, str]]) -> Optional[str]:
         return os.getenv(value["key"])
 
     return None
+
+
+def get_integration_from_extension(
+    experiment: Experiment, name: str
+) -> Dict[str, Any]:
+    extensions = experiment.setdefault("extensions", [])
+    extension = {"name": "reliably"}
+    for x in extensions:
+        if x["name"] == "reliably":
+            extension = x
+            break
+    else:
+        extensions.append(extension)
+
+    integrations = extension.setdefault("integrations", {})  # type: ignore
+    integration = integrations.setdefault(name, {})  # type: ignore
+    return integration  # type: ignore
