@@ -1,10 +1,9 @@
 from typing import Any, Optional
 
 from chaoslib.run import EventHandlerRegistry
-from chaoslib.types import Configuration, Secrets
-from logzero import logger
+from chaoslib.types import Configuration, Experiment, Secrets
 
-from . import ReliablySafeguardHandler
+from . import initialize, register, run_all
 
 __all__ = ["configure_control"]
 
@@ -17,8 +16,14 @@ def configure_control(
     secrets: Secrets = None,
     **kwargs: Any,
 ) -> None:
-    logger.debug("Configure Reliably's prechecks control")
+    initialize(event_registry)
+    register(url=url, auth=auth)
 
-    event_registry.register(
-        ReliablySafeguardHandler(url, auth, None, configuration, secrets)
-    )
+
+def before_experiment_control(
+    context: Experiment,
+    configuration: Configuration = None,
+    secrets: Secrets = None,
+    **kwargs: Any,
+) -> None:
+    run_all(context, configuration, secrets)
